@@ -2,9 +2,10 @@
 
 # Notification Center code borrowed from https://github.com/maranas/pyNotificationCenter/blob/master/pyNotificationCenter.py
 
-VERSION =   '1.2.4'
+VERSION =   '1.3.0'
 
-import os, sys, json, re, hashlib, argparse, urllib, time, base64, ConfigParser, gzip, mimetypes
+import os, sys, json, re, hashlib, argparse, urllib, time, base64, ConfigParser, gzip, mimetypes, zipfile
+from xml.dom import minidom
 
 # disable import warnings
 import warnings
@@ -24,7 +25,7 @@ def alert(text, error_code = None, color = None):
         sys.stdout.flush()
 
 # check for updates
-GIST_URL        =   'https://api.github.com/repos/dryan/d3ploy/contents/d3ploy.py'
+PYPI_URL        =   'https://pypi.python.org/pypi?:action=doap&name=d3ploy'
 CHECK_FILE      =   os.path.expanduser('~/.d3ploy-update-check')
 if not os.path.exists(CHECK_FILE):
     try:
@@ -39,20 +40,16 @@ now =   int(time.time())
 if now - last_checked > 86400:
     # it has been a day since the last update check
     try:
-        gh_data         =   json.load(urllib.urlopen(GIST_URL))
-        gh_contents     =   gh_data.get('content')
-        if gh_data.get('encoding') == 'base64':
-            gh_contents =   base64.b64decode(gh_contents)
-        version_finder  =   re.compile(r"VERSION\s+=\s+'(\d+\.\d+\.\d+)'")
-        gh_version      =   version_finder.findall(gh_contents)
-        if len(gh_version):
-            gh_version  =   gh_version.pop()
-        else:
-            gh_version  =   '0.0.0'
-        if not gh_version == VERSION:
-            alert('There has been an update for d3ploy. Version %s is now available.\nPlease see https://github.com/dryan/d3ploy or run `pip install --upgrade d3ploy`.' % gh_version, color = ALERT_COLOR)
+        pypi_data       =    minidom.parse(urllib.urlopen(PYPI_URL))
+        pypi_version    =    pypi_data.getElementsByTagName('revision')[0].firstChild.data
+        if pypi_version > VERSION:
+            alert('There has been an update for d3ploy. Version %s is now available.\nPlease see https://github.com/dryan/d3ploy or run `pip install --upgrade d3ploy`.' % pypi_version, color = ALERT_COLOR)
     except:
         pass
+    check_file  =   open(CHECK_FILE, 'w')
+    check_file.write(str(now))
+    check_file.flush()
+    check_file.close()
 
 try:
     import boto
@@ -198,7 +195,8 @@ def upload_files(env, config):
     keynames            =   []
     updated             =   0
     deleted             =   0
-            
+    caches              =   config.get('cache', {})
+
     for filename in files:
         keyname         =   '/'.join([bucket_path.rstrip('/'), prefix_regex.sub('', filename).lstrip('/')])
         keynames.append(keyname.lstrip('/'))
@@ -222,17 +220,20 @@ def upload_files(env, config):
             alert('Copying %s to %s%s' % (filename, bucket, keyname))
             updated     +=  1
             if args.dry_run:
-            	if not filename in files:
-            	    # this filename was modified by gzipping
-            	    os.remove(filename)
+                if not filename in files:
+                    # this filename was modified by gzipping
+                    os.remove(filename)
                 continue
             if s3key is None:
                 s3key   =   s3bucket.new_key(keyname)
             headers     =   {}
-            if is_gzipped or mimetypes.guess_type(filename)[1] == 'gzip':
+            mimetype    =   mimetypes.guess_type(filename)
+            if is_gzipped or mimetype[1] == 'gzip':
                 headers['Content-Encoding'] =   'gzip'
-            if args.charset or config.get('charset', False) and mimetypes.guess_type(filename)[0] and mimetypes.guess_type(filename)[0].split('/')[0] == 'text':
-            	headers['Content-Type']		=	str('%s;charset=%s' % (mimetypes.guess_type(filename)[0], args.charset or config.get('charset')))
+            if args.charset or config.get('charset', False) and mimetype[0] and mimetype[0].split('/')[0] == 'text':
+                headers['Content-Type']     =   str('%s;charset=%s' % (mimetype[0], args.charset or config.get('charset')))
+            if mimetype[0] in caches.keys():
+                s3key.set_metadata('Cache-Control', str('max-age=%s, public' % str(caches.get(mimetype[0]))))
             s3key.set_metadata('d3ploy-hash', md5)
             s3key.set_contents_from_file(local_file, headers = headers)
             s3key.set_acl(args.acl)
